discord_gleam/types/reply

Types

Our reply type, which is used to send replies to messages.

pub type Reply {
  Reply(
    message_id: snowflake.Snowflake(snowflake.Message),
    reply: message.Message,
  )
}

Constructors

Values

pub fn to_string(msg: Reply) -> String

Convert a reply to a JSON string.
Todo: deduplicate some of it cause content, embeds and components part is same as message.to_string.

Search Document