discord_gleam/types/message

Types

pub type Message {
  Message(
    content: String,
    embeds: List(embed.Embed),
    components: List(component.Component),
  )
}

Constructors

Values

pub fn add_component(
  msg: Message,
  component: component.Component,
) -> Message

Add a component to a message

pub fn add_embed(msg: Message, embed: embed.Embed) -> Message

Add a embed to a message

pub fn new(content: String) -> Message

Create a new message with the given content, no embeds and components are there by default
To add a embed or component use the add_embed and add_component functions

pub fn to_string(msg: Message) -> String
Search Document